# Hector --- A collection manager.
# Copyright © 2023 Bioneland
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import json
from http import HTTPStatus as HTTP
from typing import Any

from bl_hector.interfaces.to_http import HttpPresenter


class Dict(HttpPresenter):
    def __init__(self, data: dict[str, Any], /, *, status_code: HTTP = HTTP.OK) -> None:
        self.__status_code = status_code
        self.__headers = {"Content-Type": "application/json"}
        self.__data = data

    def status_code(self) -> int:
        return int(self.__status_code)

    def headers(self) -> dict[str, str]:
        return self.__headers

    def data(self) -> str:
        return json.dumps(self.__data)
